@@ -17,7 +17,6 @@
 from __future__ import annotations
 
 import contextlib
-import warnings
 from contextlib import closing
 from datetime import datetime
 from typing import (
@@ -37,6 +36,8 @@ from typing import (
 from urllib.parse import urlparse
 
 import sqlparse
+from deprecated import deprecated
+from more_itertools import chunked
 from sqlalchemy import create_engine
 
 from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
@@ -48,7 +49,6 @@ if TYPE_CHECKING:
     from airflow.providers.openlineage.extractors import OperatorLineage
     from airflow.providers.openlineage.sqlparser import DatabaseInfo
 
-
 T = TypeVar("T")
 
 
@@ -165,6 +165,12 @@ class DbApiHook(BaseHook):
         self.log_sql = log_sql
         self.descriptions: list[Sequence[Sequence] | None] = []
         self._placeholder: str = "%s"
+        self._insert_statement_format: str = kwargs.get(
+            "insert_statement_format", "INSERT INTO {} {} VALUES ({})"
+        )
+        self._replace_statement_format: str = kwargs.get(
+            "replace_statement_format", "REPLACE INTO {} {} VALUES ({})"
+        )
 
     @property
     def placeholder(self) -> str:
@@ -418,6 +424,14 @@ class DbApiHook(BaseHook):
         else:
             return results
 
+    @deprecated(
+        reason=(
+            "The `_make_serializable` method is deprecated and support will be removed in a future "
+            "version of the common.sql provider. Please update the DbApiHook's provider "
+            "to a version based on common.sql >= 1.9.1."
+        ),
+        category=AirflowProviderDeprecationWarning,
+    )
     def _make_common_data_structure(self, result: T | Sequence[T]) -> tuple | list[tuple]:
         """Ensure the data returned from an SQL command is a standard tuple or list[tuple].
 
@@ -432,13 +446,6 @@ class DbApiHook(BaseHook):
         # Back-compatibility call for providers implementing old ´_make_serializable' method.
         with contextlib.suppress(AttributeError):
             result = self._make_serializable(result=result)  # type: ignore[attr-defined]
-            warnings.warn(
-                "The `_make_serializable` method is deprecated and support will be removed in a future "
-                f"version of the common.sql provider. Please update the {self.__class__.__name__}'s provider "
-                "to a version based on common.sql >= 1.9.1.",
-                AirflowProviderDeprecationWarning,
-                stacklevel=2,
-            )
 
         if isinstance(result, Sequence):
             return cast(List[tuple], result)
@@ -485,13 +492,13 @@ class DbApiHook(BaseHook):
         """
         Generate the INSERT SQL statement.
 
-        The REPLACE variant is specific to MySQL syntax.
+        The REPLACE variant is specific to MySQL syntax, the UPSERT variant is specific to SAP Hana syntax
 
         :param table: Name of the target table
         :param values: The row to insert into the table
         :param target_fields: The names of the columns to fill in the table
-        :param replace: Whether to replace instead of insert
-        :return: The generated INSERT or REPLACE SQL statement
+        :param replace: Whether to replace/upsert instead of insert
+        :return: The generated INSERT or REPLACE/UPSERT SQL statement
         """
         placeholders = [
             self.placeholder,
@@ -504,13 +511,13 @@ class DbApiHook(BaseHook):
             target_fields = ""
 
         if not replace:
-            sql = "INSERT INTO "
-        else:
-            sql = "REPLACE INTO "
-        sql += f"{table} {target_fields} VALUES ({','.join(placeholders)})"
-        return sql
+            return self._insert_statement_format.format(table, target_fields, ",".join(placeholders))
 
-    def insert_rows(self, table, rows, target_fields=None, commit_every=1000, replace=False, **kwargs):
+        return self._replace_statement_format.format(table, target_fields, ",".join(placeholders))
+
+    def insert_rows(
+        self, table, rows, target_fields=None, commit_every=1000, replace=False, executemany=False, **kwargs
+    ):
         """Insert a collection of tuples into a table.
 
         Rows are inserted in chunks, each chunk (of size ``commit_every``) is
@@ -522,6 +529,8 @@ class DbApiHook(BaseHook):
         :param commit_every: The maximum number of rows to insert in one
             transaction. Set to 0 to insert all rows in one transaction.
         :param replace: Whether to replace instead of insert
+        :param executemany: Insert all rows at once in chunks defined by the commit_every parameter, only
+            works if all rows have same number of column names but leads to better performance
         """
         i = 0
         with closing(self.get_conn()) as conn:
@@ -531,19 +540,35 @@ class DbApiHook(BaseHook):
             conn.commit()
 
             with closing(conn.cursor()) as cur:
-                for i, row in enumerate(rows, 1):
-                    lst = []
-                    for cell in row:
-                        lst.append(self._serialize_cell(cell, conn))
-                    values = tuple(lst)
-                    sql = self._generate_insert_sql(table, values, target_fields, replace, **kwargs)
-                    self.log.debug("Generated sql: %s", sql)
-                    cur.execute(sql, values)
-                    if commit_every and i % commit_every == 0:
+                if executemany:
+                    for chunked_rows in chunked(rows, commit_every):
+                        values = list(
+                            map(
+                                lambda row: tuple(map(lambda cell: self._serialize_cell(cell, conn), row)),
+                                chunked_rows,
+                            )
+                        )
+                        sql = self._generate_insert_sql(table, values[0], target_fields, replace, **kwargs)
+                        self.log.debug("Generated sql: %s", sql)
+                        cur.fast_executemany = True
+                        cur.executemany(sql, values)
                         conn.commit()
-                        self.log.info("Loaded %s rows into %s so far", i, table)
+                        self.log.info("Loaded %s rows into %s so far", len(chunked_rows), table)
+                else:
+                    for i, row in enumerate(rows, 1):
+                        lst = []
+                        for cell in row:
+                            lst.append(self._serialize_cell(cell, conn))
+                        values = tuple(lst)
+                        sql = self._generate_insert_sql(table, values, target_fields, replace, **kwargs)
+                        self.log.debug("Generated sql: %s", sql)
+                        cur.execute(sql, values)
+                        if commit_every and i % commit_every == 0:
+                            conn.commit()
+                            self.log.info("Loaded %s rows into %s so far", i, table)
 
-            conn.commit()
+            if not executemany:
+                conn.commit()
         self.log.info("Done loading. Loaded a total of %s rows into %s", i, table)
 
     @staticmethod
